from setuptools import setup

setup(name='distributiongaussian',
      version='1.0',
      description='package of distribution and gausssian py',
      packages=['distributiongaussian'],
      zip_safe=False)

# Set-ExecutionPolicy -Scope CurrentUser -ExecutionPolicy Unrestricted